@@ -113,11 +113,10 @@ setMethod("show",
           signature(object = "RLum.Analysis"),
           function(object){
 
-
             ##print
             cat("\n [RLum.Analysis-class]")
 
-            ##show slot originator, for compatibily reasons with old example data, here
+            ##show slot originator, for compatibly reasons with old example data, here
             ##a check
             if(.hasSlot(object, "originator")){cat("\n\t originator:", paste0(object@originator,"()"))}
 
@@ -127,14 +126,12 @@ setMethod("show",
 
             #skip this part if nothing is included in the object
             if(length(object@records) > 0){
-
               ##get object class types
               temp <- vapply(object@records, function(x){
-                is(x)[1]
+                class(x)[1]
 
               }, FUN.VALUE = vector(mode = "character", length = 1))
 
-
               ##print object class types
               lapply(1:length(table(temp)), function(x){
 
@@ -143,9 +140,9 @@ setMethod("show",
 
                 ##show structure
                 ##set width option ... just an implementation for the tutorial output
-                ifelse(getOption("width")<=50, temp.width <- 4, temp.width  <- 7)
+                if(getOption("width")<=50) temp.width <- 4 else temp.width  <- 7
 
-                ##set linebreak variable
+                ##set line break variable
                 linebreak <- FALSE
                 env <- environment()
 
@@ -157,7 +154,6 @@ setMethod("show",
                         assign(x = "linebreak", value = TRUE, envir = env)
                       }
 
-
                       ##FIRST
                       first <-  paste0("#", i, " ", object@records[[i]]@recordType)
 
@@ -170,15 +166,14 @@ setMethod("show",
                         last <- " <> "
 
                       }else {
-                        if(i == length(object@records)){
+                        last <- " | "
+                        if (i == length(object@records)) {
                           last <- ""
 
-                        }else if (linebreak){
+                        } else if (linebreak) {
                           last <- "\n\t .. .. : "
                           assign(x = "linebreak", value = FALSE, envir = env)
 
-                        }else{
-                          last <- " | "
                         }
 
                       }
@@ -191,9 +186,12 @@ setMethod("show",
 
               }, FUN.VALUE = vector(mode = "character", length = 1))
 
-                 ##print on screen, differentiate between records with many curves or just one
+                 ##print on screen, differentiate between records with many
+                 ##curves or just one
                  if(any(grepl(terminal_output, pattern = "<>", fixed = TRUE))){
-                   cat("\n\t .. .. : ", gsub(pattern = "|", replacement = "\n\t .. .. :", x = terminal_output, fixed = TRUE), sep = "")
+                   cat("\n\t .. .. : ",
+                       gsub(pattern = "|", replacement = "\n\t .. .. :",
+                            x = terminal_output, fixed = TRUE), sep = "")
 
                  } else{
                    cat("\n\t .. .. : ", terminal_output, sep = "")
@@ -259,7 +257,7 @@ setMethod(
     newRLumAnalysis <- new(Class = "RLum.Analysis")
 
     ##allow self set to reset an RLum.Analysis object
-    if(class(records) == "RLum.Analysis"){
+    if(inherits(records, "RLum.Analysis")){
       #fill slots (this is much faster than the old code!)
       newRLumAnalysis@protocol <- if(missing(protocol)){records@protocol}else{protocol}
       newRLumAnalysis@originator <- originator
@@ -288,11 +286,11 @@ setMethod(
 #' @describeIn RLum.Analysis
 #' Accessor method for RLum.Analysis object.
 #'
-#' The slots record.id, recordType, curveType and RLum.type are optional to allow for records
-#' limited by their id (list index number), their record type (e.g. recordType = "OSL")
+#' The slots record.id, `@recordType`, `@curveType` and `@RLum.type` are optional to allow for records
+#' limited by their id (list index number), their record type (e.g. `recordType = "OSL"`)
 #' or object type.
 #'
-#' Example: curve type (e.g. curveType = "predefined" or curveType ="measured")
+#' Example: curve type (e.g. `curveType = "predefined"` or `curveType ="measured"`)
 #'
 #' The selection of a specific RLum.type object superimposes the default selection.
 #' Currently supported objects are: RLum.Data.Curve and RLum.Data.Spectrum
@@ -318,7 +316,7 @@ setMethod(
 #' return a numeric vector with the index of each element in the RLum.Analysis object.
 #'
 #' @param recursive [`get_RLum`]: [logical] (*with default*):
-#' if `TRUE` (the default) and the result of the 'get_RLum' request is a single
+#' if `TRUE` (the default) and the result of the `get_RLum()` request is a single
 #' object this object will be unlisted, means only the object itself and no
 #' list containing exactly one object is returned. Mostly this makes things
 #' easier, however, if this method is used within a loop this might be undesired.
@@ -381,7 +379,7 @@ setMethod("get_RLum",
               ), stringsAsFactors = FALSE)
 
               ##check for a logical expression, to avoid problems afterwards
-              # if(class(eval(substitute(subset), envir = envir, enclos = env)) != "logical")
+              # if(class(eval(substitute(subset), envir = envir, enclos = env))[1] != "logical")
               #   stop("[get_RLum] The argument 'subset' does not contain a logical expression!", call. = FALSE)
 
               ##select relevant rows
@@ -391,7 +389,8 @@ setMethod("get_RLum",
                 enclos = env
               ),
               error = function(e) {
-                stop("[get_RLum()] Invalid subset options. \nValid terms are: ", paste(names(envir), collapse = ", "), call. = FALSE)
+                stop("[get_RLum()] Invalid subset options. \nValid terms are: ", paste(names(envir), collapse = ", "),
+                     call. = FALSE)
               })
 
               if (all(is.na(sel)))
@@ -401,7 +400,8 @@ setMethod("get_RLum",
                 object@records <- object@records[sel]
                 return(object)
               } else {
-                tmp <- mapply(function(name, op) { message("  ",name, ": ", paste(unique(op),  collapse = ", ")) }, names(envir), envir)
+                tmp <- mapply(function(name, op) { message("  ",name, ": ", paste(unique(op),  collapse = ", ")) },
+                              names(envir), envir)
                 message("\n [get_RLum()] Invalid value, please refer to unique options given above.")
                 return(NULL)
               }
@@ -467,12 +467,11 @@ setMethod("get_RLum",
 
               ##recordType
               if (is.null(recordType)) {
-                recordType <- unique(unlist(lapply(1:length(object@records),
-                                                   function(x) {
-                                                     object@records[[x]]@recordType
-                                                   })))
+                recordType <-
+                  unique(vapply(object@records, function(x)
+                    x@recordType, character(1)))
 
-              } else if (class(recordType) != "character"){
+              } else if (!inherits(recordType, "character")){
                   stop("[get_RLum()] 'recordType' has to be of type 'character'!", call. = FALSE)
 
               }
@@ -516,14 +515,11 @@ setMethod("get_RLum",
 
               }
 
-
               ##-----------------------------------------------------------------##
-
               ##a pre-selection is necessary to support negative index selection
               object@records <- object@records[record.id]
               record.id <- 1:length(object@records)
 
-
               ##select curves according to the chosen parameter
               if (length(record.id) > 1) {
                 temp <- lapply(record.id, function(x) {
@@ -532,10 +528,7 @@ setMethod("get_RLum",
                     temp <- lapply(1:length(recordType), function(k) {
                       ##translate input to regular expression
                       recordType[k] <- glob2rx(recordType[k])
-                      recordType[k] <- substr(recordType[k],
-                                              start = 2,
-                                              stop = nchar(recordType[k]) -
-                                                1)
+                      recordType[k] <- substr(recordType[k], start = 2, stop = nchar(recordType[k]) - 1)
 
                       if (grepl(recordType[k], object@records[[x]]@recordType) == TRUE &
                           object@records[[x]]@curveType %in% curveType) {
@@ -569,10 +562,8 @@ setMethod("get_RLum",
                 temp <- temp[!sapply(temp, is.null)]
 
                 ##check if the produced object is empty and show warning message
-                if (length(temp) == 0) {
-                  warning("[get_RLum()] This request produced an empty list of records!")
-
-                }
+                if (length(temp) == 0)
+                  warning("[get_RLum()] This request produced an empty list of records!", call. = FALSE)
 
                 ##remove list for get.index
                 if (get.index) {
@@ -631,7 +622,6 @@ setMethod("get_RLum",
 
           })
 
-
 # structure_RLum() ----------------------------------------------------------------------------
 ###
 #' @describeIn RLum.Analysis
