@@ -1,9 +1,10 @@
-#' Analyse post-IR IRSL measurement sequences
+#' @title Analyse post-IR IRSL measurement sequences
 #'
-#' The function performs an analysis of post-IR IRSL sequences including curve
+#' @description The function performs an analysis of post-IR IRSL sequences
+#' including curve
 #' fitting on [RLum.Analysis-class] objects.
 #'
-#' To allow post-IR IRSL protocol (Thomsen et al., 2008) measurement analyses
+#' @details To allow post-IR IRSL protocol (Thomsen et al., 2008) measurement analyses
 #' this function has been written as extended wrapper function for the function
 #' [analyse_SAR.CWOSL], facilitating an entire sequence analysis in
 #' one run. With this, its functionality is strictly limited by the
@@ -26,7 +27,7 @@
 #'
 #' @param object [RLum.Analysis-class] or [list] of [RLum.Analysis-class] objects (**required**):
 #' input object containing data for analysis.
-#' If a [list] is provided the functions tries to iteratre over the list.
+#' If a [list] is provided the functions tries to iterate over the list.
 #'
 #' @param signal.integral.min [integer] (**required**):
 #' lower bound of the signal integral. Provide this value as vector for different
@@ -74,7 +75,7 @@
 #' \tabular{lll}{
 #' **DATA.OBJECT** \tab **TYPE** \tab **DESCRIPTION** \cr
 #' `..$data` : \tab  `data.frame` \tab Table with De values \cr
-#' `..$LnLxTnTx.table` : \tab `data.frame` \tab with the LnLxTnTx values \cr
+#' `..$LnLxTnTx.table` : \tab `data.frame` \tab with the `LnLxTnTx` values \cr
 #' `..$rejection.criteria` : \tab [data.frame] \tab rejection criteria \cr
 #' `..$Formula` : \tab [list] \tab Function used for fitting of the dose response curve \cr
 #' `..$call` : \tab [call] \tab the original function call
@@ -86,12 +87,11 @@
 #' Best graphical output can be achieved by using the function `pdf`
 #' with the following options:
 #'
-#' `pdf(file = "...", height = 15, width = 15)`
+#' `pdf(file = "<YOUR FILENAME>", height = 15, width = 15)`
 #'
 #' @section Function version: 0.2.4
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
-#' (France)
+#' @author Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
 #'
 #' @seealso [analyse_SAR.CWOSL], [calc_OSLLxTxRatio], [plot_GrowthCurve],
 #' [RLum.Analysis-class], [RLum.Results-class] [get_RLum]
@@ -99,12 +99,12 @@
 #' @references
 #' Murray, A.S., Wintle, A.G., 2000. Luminescence dating of quartz
 #' using an improved single-aliquot regenerative-dose protocol. Radiation
-#' Measurements 32, 57-73. doi:10.1016/S1350-4487(99)00253-X
+#' Measurements 32, 57-73. \doi{10.1016/S1350-4487(99)00253-X}
 #'
 #' Thomsen, K.J., Murray, A.S., Jain, M., Boetter-Jensen, L., 2008. Laboratory
 #' fading rates of various luminescence signals from feldspar-rich sediment
 #' extracts. Radiation Measurements 43, 1474-1486.
-#' doi:10.1016/j.radmeas.2008.06.002
+#' \doi{10.1016/j.radmeas.2008.06.002}
 #'
 #' @keywords datagen plot
 #'
@@ -152,7 +152,8 @@
 #' ##(3) Perform pIRIR analysis (for this example with quartz OSL data!)
 #' ## Alternative for PDF output, uncomment and complete for usage
 #' \dontrun{
-#' pdf(file = "...", height = 15, width = 15)
+#' tempfile <- tempfile(fileext = ".pdf")
+#' pdf(file = tempfile, height = 15, width = 15)
 #'   results <- analyse_pIRIRSequence(object,
 #'          signal.integral.min = 1,
 #'          signal.integral.max = 2,
@@ -220,7 +221,7 @@ analyse_pIRIRSequence <- function(
     if("main" %in% names(list(...))){
       main_list <- rep(list(...)$main, length.out = length(object))
 
-      if(class(main_list) != "list"){
+      if(!inherits(main_list, "list")){
         main_list <- as.list(main_list)
 
       }
