@@ -67,7 +67,7 @@
 #' f <- function() {
 #'  warning("warning 1")
 #'  warning("warning 1")
-#'  warning("warnigs 2")
+#'  warning("warning 2")
 #'  1:10
 #' }
 #' print(.warningCatcher(f()))
@@ -83,9 +83,11 @@
   results <- withCallingHandlers(
     expr = expr,
     warning = function(c) {
+      temp <- c(get("warning_collector", envir = env), c[[1]])
       assign(x = "warning_collector",
-             value = c,
+             value = temp,
              envir = env)
+      ##TODO should be replaced tryInvokeRestart if R 4.1 was released
       invokeRestart("muffleWarning")
     }
   )
@@ -259,7 +261,7 @@ fancy_scientific <- function(l) {
 .create_StatisticalSummaryText <- function(
   x = NULL, #insert the output of calc_Statistics
   keywords = NULL,
-  digits = 2, #allow for different digts
+  digits = 2, #allow for different digits
   sep = " \n ",
   prefix = "",
   suffix = ""
@@ -438,7 +440,7 @@ fancy_scientific <- function(l) {
 
 
   # The only check ------------------------------------------------------------------------------
-  if(class(m)[1] != "matrix")
+  if(!inherits(m, "matrix"))
     stop("[.matrix_binning()] Input is not of class 'matrix'!", call. = FALSE)
 
   # transpose in column mode --------------------------------------------------------------------
@@ -492,7 +494,7 @@ fancy_scientific <- function(l) {
 }
 
 #++++++++++++++++++++++++++++++
-#+ .expand_Parameters         +
+#+ .expand_parameters         +
 #++++++++++++++++++++++++++++++
 #' @title Expand function parameters of self-call
 #'
@@ -524,13 +526,22 @@ fancy_scientific <- function(l) {
   args_default <- as.list(f_def)[-length(as.list(f_def))][-1]
   args_new <- as.list(match.call(f_def, f_call, FALSE))[-c(1:2)]
 
-  ##combine the two arguments
+  ##now we have to make sure that we evaluate all language objects
+  ##before passing them further down
+  if(length(args_new) > 0){
+    for(i in 1:length(args_new)){
+      if(class(args_new[[i]])[1] == "name" | class(args_new[[i]])[1] == "call")
+        args_new[[i]] <- eval(args_new[[i]])
+    }
+  }
+
+  ##combine the two argument lists
   args <- modifyList(
     x = args_default,
     val = args_new,
     keep.null = TRUE)
 
-  ##evaluate arguments
+  ##evaluate arguments and take care of missing values
   for(i in 1:length(args)){
     if(is.na(names(args[i])) || names(args[i]) == "...") next
     if(class(args[[i]])[1] == "name" & names(args[i]) != "...") {
@@ -540,25 +551,27 @@ fancy_scientific <- function(l) {
 
     ##evaluate and cover special cases
     if(!is.null(args[[i]])) args[[i]] <- eval(args[[i]])
-    if(class(args[i])[1] == "list" & length(args[[i]]) == 0) args[[i]] <- list()
+    if(inherits(args[i],  "list") & length(args[[i]]) == 0) args[[i]] <- list()
 
   }
-
   ##expand all arguments
+  ##we have two conditions and three cases
+  ##1:  the argument is a list AND the list itself is not named
+  ##    ... the case when the user what to use different values for the objects
+  ##2:  the argument is no list ...
+  ##    ... the standard automated expansion
+  ##    ... OR it is a list with names (e.g., rejection.criteria = list(recycling.ration = 10))
   for(i in 1:length(args)){
-    if(class(args[[i]])[1] == "list"){
-      args[[i]] <- rep(args[[i]], length.out = len[1])
+    if(inherits(args[[i]], "list") & is.null(names(args[[i]]))){
+      args[[i]] <- rep(args[[i]], length = len[1])
 
     } else {
-      args[[i]] <- rep(
-        list(args[[i]]), length = len[1])
+      args[[i]] <- rep(list(args[[i]]), length = len[1])
 
     }
-
   }
 
   return(args)
-
 }
 
 #++++++++++++++++++++++++++++++
@@ -605,13 +618,16 @@ fancy_scientific <- function(l) {
   m <- cbind(matrix(c(dens$x, dens$y), ncol = 2), dens$y * diff)
   o <- order(m[, 3], decreasing = TRUE)
   m_ind <- which(cumsum(m[o, 3]) <= prob)
-  thres <- min(m[o, 2][m_ind])
+  thres <- suppressWarnings(min(m[o, 2][m_ind]))
 
   ##get peaks
   peaks_id <- which(abs(diff((m[,2] - thres) > 0)) == 1)
 
   ##calculate HPDI
-  HPDI <- matrix(m[peaks_id,1], ncol = 2)
+  HPDI <- matrix(NA, ncol = 2, nrow = 1)
+  if(length(peaks_id != 0))
+    HPDI <- matrix(m[peaks_id,1], ncol = 2)
+
   colnames(HPDI) <- c("lower", "upper")
   attr(HPDI, "Probabilty") <- prob
 
@@ -619,9 +635,11 @@ fancy_scientific <- function(l) {
     xy <- m[m_ind,c(1,2)]
     plot(dens, main = "HPDI (control plot)")
     abline(h = thres, lty = 2)
-    for(i in seq(1,length(peaks_id),2)) {
-      lines(x = m[peaks_id[i]:peaks_id[i + 1], 1],
-            y = m[peaks_id[i]:peaks_id[i + 1], 2], col = "red")
+    if(length(peaks_id != 0)) {
+      for(i in seq(1,length(peaks_id),2)) {
+        lines(x = m[peaks_id[i]:peaks_id[i + 1], 1],
+              y = m[peaks_id[i]:peaks_id[i + 1], 2], col = "red")
+      }
     }
 
   }
