@@ -193,7 +193,7 @@
 #' `..$call` : \tab `call` \tab The original function call\cr
 #' }
 #'
-#' @section Function version: 1.11.3
+#' @section Function version: 1.11.4
 #'
 #' @author
 #' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)\cr
@@ -323,7 +323,7 @@ plot_GrowthCurve <- function(
 
   ##1. Check input variable
   switch(
-    class(sample),
+    class(sample)[1],
     matrix = sample <- as.data.frame(sample),
     list = sample <- as.data.frame(sample),
     numeric = stop(
@@ -377,7 +377,7 @@ plot_GrowthCurve <- function(
     if (n.NA == 1) {
       warning("[plot_GrowthCurve()] 1 NA value excluded.", call. = FALSE)
     } else if (n.NA > 1) {
-      warning(paste(" [plot_GrowthCurve()]", n.NA, "NA values excluded."), call. = FALSE)
+      warning(paste("[plot_GrowthCurve()]", n.NA, "NA values excluded."), call. = FALSE)
     }
 
     sample <- na.exclude(sample)
@@ -440,19 +440,13 @@ plot_GrowthCurve <- function(
   if(fit.weights){
     fit.weights <- 1 / abs(y.Error) / sum(1 / abs(y.Error))
 
-    if(is.na(fit.weights[1])){
-      fit.weights <- NA
-      warning("[plot_GrowthCurve()] 'fit.weights' set to NA since the error column is invalid or 0.", call. = FALSE)
+    if(any(is.na(fit.weights))){
+      fit.weights <- 1
+      warning("[plot_GrowthCurve()] 'fit.weights' ignored since the error column is invalid or 0.", call. = FALSE)
 
     }
-
   }else{
-    if(sum(y.Error) == 0) {
-      fit.weights <- NA
-
-    } else {
-      fit.weights <- rep(1, length(abs(y.Error)))
-    }
+      fit.weights <- rep(1, length(y.Error))
 
   }
 
@@ -577,7 +571,7 @@ plot_GrowthCurve <- function(
   ##    (suppress the warning in case one parameter is negative)
   fit.lm <- try(lm(suppressWarnings(log(data$y))~data$x))
 
-  if(class(fit.lm) == "try-error"){
+  if(inherits(fit.lm, "try-error")){
     b <- 1
 
   }else{
@@ -836,7 +830,7 @@ plot_GrowthCurve <- function(
         ))
 
 
-        if(class(fit.initial)!="try-error"){
+        if(!inherits(fit.initial, "try-error")){
           #get parameters out of it
           parameters<-(coef(fit.initial))
           b.start[i] <- as.vector((parameters["b"]))
@@ -965,7 +959,7 @@ plot_GrowthCurve <- function(
           )
 
           #get parameters out of it including error handling
-          if (class(fit.MC)=="try-error") {
+          if (inherits(fit.MC, "try-error")) {
             x.natural[i] <- NA
 
           }else {
@@ -1011,7 +1005,7 @@ plot_GrowthCurve <- function(
     #set fit object, if fit object was not set before
     if(exists("fit")==FALSE){fit<-NA}
 
-    if ((fit.method=="EXP OR LIN" & class(fit)=="try-error") |
+    if ((fit.method=="EXP OR LIN" & inherits(fit, "try-error")) |
         fit.method=="LIN" | length(data[,1])<2) {
 
       ##Do fitting again as just allows fitting through the origin
@@ -1133,7 +1127,7 @@ plot_GrowthCurve <- function(
                        nls.control(maxiter=100,warnOnly=FALSE,minFactor=1/1024)
       ),silent=TRUE)
 
-      if(class(fit.EXP)!="try-error"){
+      if(!inherits(fit.EXP, "try-error")){
         #get parameters out of it
         parameters<-(coef(fit.EXP))
         b<-as.vector((parameters["b"]))
@@ -1155,7 +1149,7 @@ plot_GrowthCurve <- function(
                    nls.control(maxiter=500,warnOnly=FALSE,minFactor=1/2048) #increase max. iterations
       ),silent=TRUE)
 
-      if(class(fit)!="try-error"){
+      if(!inherits(fit, "try-error")){
         #get parameters out of it
         parameters<-(coef(fit))
         b.start[i]<-as.vector((parameters["b"]))
@@ -1200,7 +1194,7 @@ plot_GrowthCurve <- function(
 
 
     #if try error stop calculation
-    if(class(fit)!="try-error"){
+    if(!inherits(fit, "try-error")){
 
       #get parameters out of it
       parameters<-(coef(fit))
@@ -1233,7 +1227,7 @@ plot_GrowthCurve <- function(
 
 
 
-        if (class(temp.De) != "try-error") {
+        if (!inherits(temp.De, "try-error")) {
           De <- temp.De$root
         } else{
           De <- NA
@@ -1259,7 +1253,7 @@ plot_GrowthCurve <- function(
           silent = TRUE)
 
 
-          if (class(temp.De) != "try-error") {
+          if (!inherits(temp.De, "try-error")) {
             De <- temp.De$root
           } else{
             De <- NA
@@ -1326,7 +1320,7 @@ plot_GrowthCurve <- function(
         )
 
         #get parameters out of it including error handling
-        if (class(fit.MC)=="try-error") {
+        if (inherits(fit.MC, "try-error")) {
 
           x.natural[i]<-NA
 
@@ -1353,7 +1347,7 @@ plot_GrowthCurve <- function(
             ),
             silent = TRUE)
 
-            if (class(temp.De.MC) != "try-error") {
+            if (!inherits(temp.De.MC, "try-error")) {
               x.natural[i] <- temp.De.MC$root
             } else{
               x.natural[i] <- NA
@@ -1371,7 +1365,7 @@ plot_GrowthCurve <- function(
             ),
             silent = TRUE)
 
-            if (class(temp.De.MC) != "try-error") {
+            if (!inherits(temp.De.MC, "try-error")) {
               x.natural[i] <- abs(temp.De.MC$root)
             } else{
               x.natural[i] <- NA
@@ -1442,7 +1436,7 @@ plot_GrowthCurve <- function(
       ),silent = TRUE)
 
 
-      if (class(fit.start) != "try-error") {
+      if (!inherits(fit.start, "try-error")) {
         #get parameters out of it
         parameters <- coef(fit.start)
         a1.start[i] <- as.vector((parameters["a1"]))
@@ -1477,7 +1471,7 @@ plot_GrowthCurve <- function(
 
 
     ##insert if for try-error
-    if (class(fit)!="try-error") {
+    if (!inherits(fit, "try-error")) {
 
       #get parameters out of it
       parameters <- (coef(fit))
@@ -1513,7 +1507,7 @@ plot_GrowthCurve <- function(
         silent = TRUE)
 
 
-        if (class(temp.De) != "try-error") {
+        if (!inherits(temp.De, "try-error")) {
           De <- temp.De$root
         } else{
           De <- NA
@@ -1580,7 +1574,7 @@ plot_GrowthCurve <- function(
         )
 
         #get parameters out of it including error handling
-        if (class(fit.MC)=="try-error") {
+        if (inherits(fit.MC, "try-error")) {
           x.natural[i]<-NA
 
         }else {
@@ -1603,7 +1597,7 @@ plot_GrowthCurve <- function(
             LnTn = data.MC.De[i]
           ), silent = TRUE)
 
-          if (class(temp.De.MC) != "try-error") {
+          if (!inherits(temp.De.MC, "try-error")) {
             x.natural[i] <- temp.De.MC$root
           }else{
             x.natural[i] <- NA
@@ -1738,7 +1732,7 @@ plot_GrowthCurve <- function(
         )}, silent = TRUE)
 
         # get parameters out of it including error handling
-        if (class(fit.MC)=="try-error") {
+        if (inherits(fit.MC, "try-error")) {
           x.natural[i] <- NA
 
         } else {
