@@ -1,7 +1,6 @@
-context("read_RF2R")
-
 test_that("Test functionality", {
   testthat::skip_on_cran()
+  local_edition(3)
 
   ##load file path
   file <- system.file("extdata", "RF_file.rf", package = "Luminescence")
